@@ -16,7 +16,7 @@ import numpy as np
 from sklearn.datasets import load_boston
 
 from featurebox.selection.mutibase import MutiBase
-from featurebox.tools.tool import name_to_name
+from mgetool.tool import name_to_name
 
 
 class Corr(MutiBase):
