@@ -18,11 +18,11 @@ import numpy as np
 from sklearn.base import BaseEstimator
 from sklearn.base import MetaEstimatorMixin
 from sklearn.base import clone
-from sklearn.feature_selection._base import SelectorMixin
+from sklearn.feature_selection.base import SelectorMixin
 from sklearn.utils.metaestimators import if_delegate_has_method
 from sklearn.utils.validation import check_is_fitted, check_X_y
 
-from featurebox.tools.tool import parallelize
+from mgetool.tool import parallelize
 from .mutibase import MutiBase
 
 warnings.filterwarnings("ignore")
