@@ -313,7 +313,7 @@ def dict_me(me="clf"):
     return dict_method_
 
 
-def method_pack(method_all, me="reg", gd=True):
+def method_pack(method_all, me="reg", scoreing=None, gd=True, cv=10):
     if not method_all:
         method_all = ['KNR-set', 'SVR-set', "KRR-set", "GPR-set",
                       "RFR-em", "AdaBR-em", "DTR-em",
@@ -326,9 +326,10 @@ def method_pack(method_all, me="reg", gd=True):
         for method_i in method_all:
             me2, cv2, scoring2, param_grid2 = dict_method[method_i]
             if me == "clf":
-                scoring2 = 'balanced_accuracy'
+                scoring2 = scoreing if scoreing else 'balanced_accuracy'
             if me == "reg":
-                scoring2 = 'r2'
+                scoring2 = scoreing if scoreing else 'r2'
+            cv2  = cv if cv else cv2
             gd2 = GridSearchCV(me2, cv=cv2, param_grid=param_grid2, scoring=scoring2, n_jobs=1)
             estimator.append(gd2)
         return estimator
@@ -337,9 +338,10 @@ def method_pack(method_all, me="reg", gd=True):
         for method_i in method_all:
             me2, cv2, scoring2, param_grid2 = dict_method[method_i]
             if me == "clf":
-                scoring2 = 'balanced_accuracy'
+                scoring2 = scoreing if scoreing else 'balanced_accuracy'
             if me == "reg":
-                scoring2 = 'r2'
+                scoring2 = scoreing if scoreing else 'r2'
+            cv2 = cv if cv else cv2
             gd2 = partial(cross_val_score, estimator=me2, cv=cv2, scoring=scoring2)
             # gd2 = cross_val_score(me2, cv=cv2, scoring=scoring2)
             estimator.append(gd2)
