@@ -36,7 +36,7 @@ from sklearn.model_selection import KFold, GridSearchCV, StratifiedKFold
 from sklearn.utils import check_X_y, check_random_state
 from sklearn.utils.multiclass import type_of_target
 
-from featurebox.tools.tool import parallelize
+from mgetool.tool import parallelize
 
 warnings.filterwarnings("ignore")
 
